==> htsct-0.0.22-py3-none-any.whl: htsct/core/highThroughput.py <==
import random
import time
from os.path import join
from htsct import BandCalc, BandPlot
from htsct.constants import TASK_LOG, FIGS_PATH, DB_DIR, VASP_STD, WAIT_INTERVAL, SYSTEM_LOG
from htsct.core.dataAnalysis import DataExtractor
from htsct.utils.tools import copyFile
from pathlib import Path
import wrapt


def endless(time_step=WAIT_INTERVAL):
    # def decorator(func):
    @wrapt.decorator
    def wrapper(wrapped, instance, args, kwargs):
        cwd = Path.cwd()
        count = 0
        A = set()
        while True:
            B = set()  # 用于本地保存所有.cif路径
            for i in cwd.iterdir():
                if i.is_file() and i.name.endswith(".cif") and not i.name.startswith("."):
                    B.add(cwd / i.name[0:-4])
            C = A | B  # 两个集合相加
            D = C - A  # 判断是否有差别
            if not D:
                count += 1
                time.sleep(1)
                if count >= time_step:
                    break
                continue
            work_path = random.choice(list(D))
            # try:
            work_path.mkdir(parents=True, exist_ok=True)
            cif = f"{work_path.name}.cif"
            (cwd / cif).replace(work_path / cif)
            wrapped(work_path=work_path, *args, **kwargs)
            A.add(work_path)
            # except Exception as e:
            #     with SYSTEM_LOG.open("a+", encoding="utf-8") as fd:
            #         fd.write(f"{work_path}:{e}\n")

    return wrapper

    # return decorator


@endless()
def band_high_throughput(struct, scf, band, table_name, **kwargs):
    work_path = kwargs.pop("work_path")
    bandCalc = BandCalc(work_path, TASK_LOG, VASP_STD)
    dataExtractor = DataExtractor(work_path, DB_DIR, table_name)
    bandCalc.struct(**struct)
    dataExtractor.structDataWriter()
    bandCalc.scf(**scf)
    dataExtractor.scfDataWriter()
    bandCalc.band(**band)
    dataExtractor.bandDataWriter()
    dataExtractor.clearFiles()
    band_path = dataExtractor.target_path / "band"
    BandPlot(band_path).band_dos()
    #
    # 2.Files collect.
    #
    _FIG_PATH = join(FIGS_PATH, bandCalc.root.name)
    copyFile(band_path, _FIG_PATH, "band2.png")
    copyFile(band_path, _FIG_PATH, "banddos_fig.png")
    copyFile(band_path, _FIG_PATH, "Band_Position_Info")

==> htsct-0.0.27-py3-none-any.whl: htsct/core/highThroughput.py <==
import random
import time
from os.path import join
from htsct import BandCalc, BandPlot
from htsct.constants import TASK_LOG, FIGS_PATH, DB_DIR, VASP_STD, WAIT_INTERVAL, SYSTEM_LOG, INPUT_FILE_TYPE
from htsct.core.dataAnalysis import DataExtractor
from htsct.utils.tools import copyFile
from pathlib import Path
import wrapt


def endless(time_step=WAIT_INTERVAL, ftype=INPUT_FILE_TYPE):
    @wrapt.decorator
    def wrapper(wrapped, instance, args, kwargs):
        cwd = Path.cwd()
        count = 0
        A = set()
        while True:
            B = set()  # 用于本地保存所有.cif路径
            for i in cwd.iterdir():
                if i.is_file() and i.name.endswith(ftype) and not i.name.startswith("."):
                    B.add(cwd / i.name[0:-len(ftype)])
            C = A | B  # 两个集合相加
            D = C - A  # 判断是否有差别
            if not D:
                count += 1
                time.sleep(1)
                if count >= time_step:
                    break
                continue
            work_path = random.choice(list(D))
            try:
                work_path.mkdir(parents=True, exist_ok=True)
                input_file = f"{work_path.name}{ftype}"
                (cwd / input_file).replace(work_path / input_file)
                wrapped(work_path=work_path, *args, **kwargs)
                A.add(work_path)
            except Exception as e:
                with SYSTEM_LOG.open("a+", encoding="utf-8") as fd:
                    fd.write(f"{work_path}:{e}\n")

    return wrapper


@endless()
def band_high_throughput(struct, scf, band, table_name, **kwargs):
    work_path = kwargs.pop("work_path")
    bandCalc = BandCalc(work_path, TASK_LOG, VASP_STD)
    dataExtractor = DataExtractor(work_path, DB_DIR, table_name)
    bandCalc.struct(**struct)
    dataExtractor.structDataWriter()
    bandCalc.scf(**scf)
    dataExtractor.scfDataWriter()
    bandCalc.band(**band)
    dataExtractor.bandDataWriter()
    band_path = dataExtractor.target_path / "band"
    BandPlot(band_path).band_dos()
    #
    # 2.Files collect.
    #
    _FIG_PATH = join(FIGS_PATH, bandCalc.root.name)
    copyFile(band_path, _FIG_PATH, "band2.png")
    copyFile(band_path, _FIG_PATH, "banddos_fig.png")
    copyFile(band_path, _FIG_PATH, "Band_Position_Info")

    dataExtractor.clearFiles()
